Installation — mod_wsgi 4.8.0 documentation

# Installation

The mod_wsgi package can be installed from source code or may also be available as a pre built binary package as part of your Linux distribution.

Do be aware though that Linux distributions generally ship out of date versions of mod_wsgi and for long term support (LTS) versions of Linux can be anything up to about 5 years old. Those older versions are not supported in any way even though they are part of a so called LTS version of Linux.

If you want support and want to ensure you have the most up to date and bug free version of mod_wsgi, you should consider building and installing mod_wsgi from the source code.

For instructions on how to compile mod_wsgi from the source code for UNIX like operating systems such as Linux and MacOS X see:

> - Quick Installation Guide
> - Installation On MacOS X

If you are on Windows, you should instead use:

> - https://github.com/GrahamDumpleton/mod_wsgi/blob/develop/win32/README.rst